==> eiffelstudio-18.01.10.1424.tar: F_code/C26/gb1267.c <==
/*
 * Code for class GB_EV_MULTI_COLUMN_LIST_ROW_SELECT_ACTION_SEQUENCE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb1267.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_EV_MULTI_COLUMN_LIST_ROW_SELECT_ACTION_SEQUENCE}.argument_types */
static EIF_REFERENCE F2066_22951_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("argument_types", 2065, Current, 0, 0, 28905);
	RTGC;
	RTOSP (22951);
#define Result RTOSR(22951)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1373,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9928(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("EV_MULTI_COLUMN_LIST_ROW",24,292297303);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (22951);
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F2066_22951 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(22951,F2066_22951_body,(Current));
}

/* {GB_EV_MULTI_COLUMN_LIST_ROW_SELECT_ACTION_SEQUENCE}.argument_names */
static EIF_REFERENCE F2066_22952_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("argument_names", 2065, Current, 0, 0, 28906);
	RTGC;
	RTOSP (22952);
#define Result RTOSR(22952)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1373,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9928(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("an_item",7,1415897197);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (22952);
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F2066_22952 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(22952,F2066_22952_body,(Current));
}

void EIF_Minit1267 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C26/gb1267.c <==
/*
 * Code for class GB_EV_POINTER_BUTTON_ACTION_SEQUENCE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb1267.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_EV_POINTER_BUTTON_ACTION_SEQUENCE}.argument_types */
static EIF_REFERENCE F2066_22953_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("argument_types", 2065, Current, 0, 0, 28918);
	RTGC;
	RTOSP (22953);
#define Result RTOSR(22953)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1376,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9931(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("INTEGER",7,1551244370);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS_EX_H("INTEGER",7,1551244370);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(4);
	tr1 = RTMS_EX_H("INTEGER",7,1551244370);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(5);
	tr1 = RTMS_EX_H("DOUBLE",6,1564708421);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(6);
	tr1 = RTMS_EX_H("DOUBLE",6,1564708421);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(7);
	tr1 = RTMS_EX_H("DOUBLE",6,1564708421);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(8);
	tr1 = RTMS_EX_H("INTEGER",7,1551244370);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(9);
	tr1 = RTMS_EX_H("INTEGER",7,1551244370);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (22953);
	RTHOOK(10);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F2066_22953 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(22953,F2066_22953_body,(Current));
}

/* {GB_EV_POINTER_BUTTON_ACTION_SEQUENCE}.argument_names */
static EIF_REFERENCE F2066_22954_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("argument_names", 2065, Current, 0, 0, 28919);
	RTGC;
	RTOSP (22954);
#define Result RTOSR(22954)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1376,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9931(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("a_x",3,6381432);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS_EX_H("a_y",3,6381433);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(4);
	tr1 = RTMS_EX_H("a_button",8,592740974);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(5);
	tr1 = RTMS_EX_H("a_x_tilt",8,635104116);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(6);
	tr1 = RTMS_EX_H("a_y_tilt",8,637070196);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(7);
	tr1 = RTMS_EX_H("a_pressure",10,789079141);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(8);
	tr1 = RTMS_EX_H("a_screen_x",10,1620049272);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(9);
	tr1 = RTMS_EX_H("a_screen_y",10,1620049273);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (22954);
	RTHOOK(10);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F2066_22954 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(22954,F2066_22954_body,(Current));
}

void EIF_Minit1267 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
